pub enum TextError {
IndexOutOfBounds {
index: usize,
len: usize,
},
RangeOutOfBounds {
start: usize,
end: usize,
len: usize,
},
}Expand description
Error type for TextCrdt operations.
Variants
IndexOutOfBounds
Index is out of bounds for the current visible text length.
RangeOutOfBounds
Range is out of bounds for the current visible text length.