pub struct MVRegister<T: Clone + Ord> { /* private fields */ }Expand description
A multi-value register (MV-Register).
Unlike LWW-Register, this preserves all concurrently written values. When concurrent writes occur, all values are kept until a subsequent write supersedes them. This is useful when you want to detect conflicts rather than silently resolving them.
Example
use crdt_kit::prelude::*;
let mut r1 = MVRegister::new(1);
r1.set("alice");
let mut r2 = MVRegister::new(2);
r2.set("bob");
r1.merge(&r2);
// Both values are preserved as concurrent writes
let values = r1.values();
assert!(values.contains(&&"alice"));
assert!(values.contains(&&"bob"));Implementations
Sourceimpl<T: Clone + Ord> MVRegister<T>
impl<T: Clone + Ord> MVRegister<T>